#[non_exhaustive]pub struct CreateLinkInput {
pub label_template: Option<String>,
pub resource_types: Option<Vec<ResourceType>>,
pub sink_identifier: Option<String>,
pub tags: Option<HashMap<String, String>>,
pub link_configuration: Option<LinkConfiguration>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.label_template: Option<String>Specify a friendly human-readable name to use to identify this source account when you are viewing data from it in the monitoring account.
You can use a custom label or use the following variables:
-
$AccountNameis the name of the account -
$AccountEmailis the globally unique email address of the account -
$AccountEmailNoDomainis the email address of the account without the domain name
In the Amazon Web Services GovCloud (US-East) and Amazon Web Services GovCloud (US-West) Regions, the only supported option is to use custom labels, and the $AccountName, $AccountEmail, and $AccountEmailNoDomain variables all resolve as account-id instead of the specified variable.
resource_types: Option<Vec<ResourceType>>An array of strings that define which types of data that the source account shares with the monitoring account.
sink_identifier: Option<String>The ARN of the sink to use to create this link. You can use ListSinks to find the ARNs of sinks.
For more information about sinks, see CreateSink.
Assigns one or more tags (key-value pairs) to the link.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
For more information about using tags to control access, see Controlling access to Amazon Web Services resources using tags.
link_configuration: Option<LinkConfiguration>Use this structure to optionally create filters that specify that only some metric namespaces or log groups are to be shared from the source account to the monitoring account.
Implementations
Sourceimpl CreateLinkInput
impl CreateLinkInput
Sourcepub fn label_template(&self) -> Option<&str>
pub fn label_template(&self) -> Option<&str>
Specify a friendly human-readable name to use to identify this source account when you are viewing data from it in the monitoring account.
You can use a custom label or use the following variables:
-
$AccountNameis the name of the account -
$AccountEmailis the globally unique email address of the account -
$AccountEmailNoDomainis the email address of the account without the domain name
In the Amazon Web Services GovCloud (US-East) and Amazon Web Services GovCloud (US-West) Regions, the only supported option is to use custom labels, and the $AccountName, $AccountEmail, and $AccountEmailNoDomain variables all resolve as account-id instead of the specified variable.
Sourcepub fn resource_types(&self) -> &[ResourceType]
pub fn resource_types(&self) -> &[ResourceType]
An array of strings that define which types of data that the source account shares with the monitoring account.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .resource_types.is_none().
Sourcepub fn sink_identifier(&self) -> Option<&str>
pub fn sink_identifier(&self) -> Option<&str>
The ARN of the sink to use to create this link. You can use ListSinks to find the ARNs of sinks.
For more information about sinks, see CreateSink.
Assigns one or more tags (key-value pairs) to the link.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
For more information about using tags to control access, see Controlling access to Amazon Web Services resources using tags.
Sourcepub fn link_configuration(&self) -> Option<&LinkConfiguration>
pub fn link_configuration(&self) -> Option<&LinkConfiguration>
Use this structure to optionally create filters that specify that only some metric namespaces or log groups are to be shared from the source account to the monitoring account.
Sourceimpl CreateLinkInput
impl CreateLinkInput
Sourcepub fn builder() -> CreateLinkInputBuilder
pub fn builder() -> CreateLinkInputBuilder
Creates a new builder-style object to manufacture CreateLinkInput.